@@ -1,7 +1,7 @@
 package org.tanukisoftware.wrapper;
 
 /*
- * Copyright (c) 1999, 2011 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2014 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -42,6 +42,7 @@ public final class WrapperProcessConfig
     public static final int DYNAMIC = 4;
 
     private boolean m_isDetached;
+    private boolean m_isInteractive;
     private File m_defdir;
     private int m_startType;
     private Map m_environment;
@@ -72,6 +73,7 @@ public final class WrapperProcessConfig
         m_startType = DYNAMIC;
         m_environment = null;
         m_softShutdownTimeout = 5;
+        m_isInteractive = false;
     }
 
     /*---------------------------------------------------------------
@@ -98,7 +100,14 @@ public final class WrapperProcessConfig
             throw new WrapperLicenseError(  WrapperManager.getRes().getString( "Requires the Professional Edition." ) );
         }
         verifyStartType( startType );
-        return isSupportedNative( startType );
+        if ( WrapperManager.isNativeLibraryOk() )
+        {
+            return isSupportedNative( startType );
+        }
+        else
+        {
+            return false;
+        }
     }
     
     /**
@@ -361,13 +370,16 @@ public final class WrapperProcessConfig
     private Map getDefaultEnvironment()
     {
         Map environment = new HashMap();
-        String[] nativeEnv = nativeGetEnv();
-        for ( int i = 0; i < nativeEnv.length; i++ )
+        if ( WrapperManager.isNativeLibraryOk() )
         {
-            int pos = nativeEnv[i].indexOf( '=' );
-            String name = nativeEnv[i].substring( 0, pos );
-            String value = nativeEnv[i].substring( pos + 1 );
-            environment.put( name, value );
+            String[] nativeEnv = nativeGetEnv();
+            for ( int i = 0; i < nativeEnv.length; i++ )
+            {
+                int pos = nativeEnv[i].indexOf( '=' );
+                String name = nativeEnv[i].substring( 0, pos );
+                String value = nativeEnv[i].substring( pos + 1 );
+                environment.put( name, value );
+            }
         }
 
         return environment;
@@ -380,7 +392,14 @@ public final class WrapperProcessConfig
     {
         if ( m_environment == null )
         {
-            return nativeGetEnv();
+            if ( WrapperManager.isNativeLibraryOk() )
+            {
+                return nativeGetEnv();
+            }
+            else
+            {
+                return new String[0];
+            }
         }
         else
         {
@@ -395,4 +414,37 @@ public final class WrapperProcessConfig
             return nativeEnv;
         }
     }
+
+
+/**
+ *  Specifies if the ChildProcesses should be launched
+ *  in the current session. 
+ *  This property only makes sense if the application was
+ *  launched as Windows Service under the System User (or any
+ *  other user, having SE_TCB_NAME previledge with the OS)
+ *  On non-Windows platforms or when launched in Console mode,
+ *  the setting will be ignored silently.
+ *
+ * @param isInteractive true to enable the feature. 
+ */
+    public WrapperProcessConfig setCreateForActiveUser( boolean isInteractive )
+    {
+        if (WrapperManager.isWindows() && WrapperManager.isLaunchedAsService())
+        {
+            m_isInteractive = true;
+        }
+        else
+        {
+            m_isInteractive = false;
+        }
+        return this;
+    }
+
+/**
+ *  Tells if the CreateForActiveUser feature was enabled.
+ */
+    public boolean isCreateForActiveUser()
+    {
+        return m_isInteractive;
+    }
 }
